// fragment
precision mediump float; 
precision mediump int; 
precision lowp sampler2D;

uniform sampler2D u_texture;
uniform lowp int u_texturing;

uniform lowp int u_tex_mode;
uniform vec3 u_tex_colormod_color;

varying vec4 v_color;
varying vec2 v_texture_coordinate;

#define MODE_REPLACE 0
#define MODE_MODULATE 1
#define MODE_COLORMODIFICATION 2


void gaussianBlur( in sampler2D unit , in vec2 coord , in vec2 jump , inout vec4 color ) {
	// Gaussian blur.
	// 1 2 1
	// 2 1 2
	// 1 2 1 / 13
	vec4 tex = texture2D( unit , coord - jump ) + 2.0*texture2D( unit , vec2( coord.x , coord.y - jump.y ) ) + texture2D( unit , vec2( coord.x + jump.x , coord.y - jump.y ) );
	tex += 2.0*texture2D( unit , vec2( coord.x - jump.x , coord.y ) ) + texture2D( unit , coord ) + 2.0*texture2D( unit , vec2( coord.x + jump.x , coord.y ) );
	tex += texture2D( unit , vec2( coord.x - jump.x , coord.y + jump.y ) ) + 2.0*texture2D( unit , vec2( coord.x , coord.y + jump.y ) ) + texture2D( unit , coord + jump );
	
	color = tex / 13.0;
}

void blacknwhite( inout vec3 color ) {
	float col = (color.r + color.g + color.b) / 3.0;
	color = vec3( col , col , col );
}

void blacknwhite2( inout vec3 color ) {
	// a bit lighter b&w filter
	float col = max(color.r,max(color.g,color.b));
	color = vec3( col , col , col );
}

void sepia( inout vec3 color ) {
	vec3 col;
	col.r = dot(color, vec3(.393, .769, .189));
	col.g = dot(color, vec3(.349, .686, .168));
	col.b = dot(color, vec3(.272, .534, .131));
	color = col;
}

void main()
{
	if ( u_tex_mode == MODE_REPLACE ) {
		gl_FragColor = texture2D( u_texture , v_texture_coordinate );
	}
	else if ( u_tex_mode == MODE_MODULATE ) {
		gl_FragColor = v_color * texture2D( u_texture , v_texture_coordinate );
	}
	else if( u_tex_mode == MODE_COLORMODIFICATION ) {
		// Take color from texture and do colormod
		vec4 texture = texture2D( u_texture , v_texture_coordinate );
		gl_FragColor.rgb = texture.rgb + u_tex_colormod_color;
		
		// Take alpha from texture and do colormod
		gl_FragColor.a = texture.a * v_color.a;
	}
}
